@@ -1,37 +1,37 @@
-classdef ICameraAnimator < SwigRef
+classdef ICameraAnimator < iDynTreeSwigRef
   methods
     function this = swig_this(self)
       this = iDynTreeMEX(3, self);
     end
     function varargout = enableMouseControl(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1793, self, varargin{:});
-    end
-    function varargout = getMoveSpeed(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1794, self, varargin{:});
-    end
-    function varargout = setMoveSpeed(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1795, self, varargin{:});
-    end
-    function varargout = getRotateSpeed(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1796, self, varargin{:});
     end
-    function varargout = setRotateSpeed(self,varargin)
+    function varargout = getMoveSpeed(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1797, self, varargin{:});
     end
-    function varargout = getZoomSpeed(self,varargin)
+    function varargout = setMoveSpeed(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1798, self, varargin{:});
     end
-    function varargout = setZoomSpeed(self,varargin)
+    function varargout = getRotateSpeed(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1799, self, varargin{:});
     end
+    function varargout = setRotateSpeed(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1800, self, varargin{:});
+    end
+    function varargout = getZoomSpeed(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1801, self, varargin{:});
+    end
+    function varargout = setZoomSpeed(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1802, self, varargin{:});
+    end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(1800, self);
+        iDynTreeMEX(1803, self);
         self.SwigClear();
       end
     end
     function self = ICameraAnimator(varargin)
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
