@@ -1,49 +1,49 @@
-classdef LinkUnknownWrenchContacts < SwigRef
+classdef LinkUnknownWrenchContacts < iDynTreeSwigRef
   methods
     function this = swig_this(self)
       this = iDynTreeMEX(3, self);
     end
     function self = LinkUnknownWrenchContacts(varargin)
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(1442, varargin{:});
+        tmp = iDynTreeMEX(1444, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
     end
     function varargout = clear(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1443, self, varargin{:});
-    end
-    function varargout = resize(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1444, self, varargin{:});
-    end
-    function varargout = getNrOfContactsForLink(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1445, self, varargin{:});
     end
-    function varargout = setNrOfContactsForLink(self,varargin)
+    function varargout = resize(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1446, self, varargin{:});
     end
-    function varargout = addNewContactForLink(self,varargin)
+    function varargout = getNrOfContactsForLink(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1447, self, varargin{:});
     end
-    function varargout = addNewContactInFrame(self,varargin)
+    function varargout = setNrOfContactsForLink(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1448, self, varargin{:});
     end
-    function varargout = addNewUnknownFullWrenchInFrameOrigin(self,varargin)
+    function varargout = addNewContactForLink(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1449, self, varargin{:});
     end
-    function varargout = contactWrench(self,varargin)
+    function varargout = addNewContactInFrame(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1450, self, varargin{:});
     end
-    function varargout = toString(self,varargin)
+    function varargout = addNewUnknownFullWrenchInFrameOrigin(self,varargin)
       [varargout{1:nargout}] = iDynTreeMEX(1451, self, varargin{:});
     end
+    function varargout = contactWrench(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1452, self, varargin{:});
+    end
+    function varargout = toString(self,varargin)
+      [varargout{1:nargout}] = iDynTreeMEX(1453, self, varargin{:});
+    end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(1452, self);
+        iDynTreeMEX(1454, self);
         self.SwigClear();
       end
     end
