@@ -1,4 +1,4 @@
-classdef Polygon < SwigRef
+classdef Polygon < iDynTreeSwigRef
   methods
     function this = swig_this(self)
       this = iDynTreeMEX(3, self);
@@ -7,48 +7,48 @@ classdef Polygon < SwigRef
       narginchk(1, 2)
       if nargin==1
         nargoutchk(0, 1)
-        varargout{1} = iDynTreeMEX(1921, self);
+        varargout{1} = iDynTreeMEX(1942, self);
       else
         nargoutchk(0, 0)
-        iDynTreeMEX(1922, self, varargin{1});
+        iDynTreeMEX(1943, self, varargin{1});
       end
     end
     function self = Polygon(varargin)
-      if nargin==1 && strcmp(class(varargin{1}),'SwigRef')
+      if nargin==1 && strcmp(class(varargin{1}),'iDynTreeSwigRef')
         if ~isnull(varargin{1})
           self.swigPtr = varargin{1}.swigPtr;
         end
       else
-        tmp = iDynTreeMEX(1923, varargin{:});
+        tmp = iDynTreeMEX(1944, varargin{:});
         self.swigPtr = tmp.swigPtr;
         tmp.SwigClear();
       end
     end
     function varargout = setNrOfVertices(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1924, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(1945, self, varargin{:});
     end
     function varargout = getNrOfVertices(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1925, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(1946, self, varargin{:});
     end
     function varargout = isValid(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1926, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(1947, self, varargin{:});
     end
     function varargout = applyTransform(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1927, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(1948, self, varargin{:});
     end
     function varargout = paren(self,varargin)
-      [varargout{1:nargout}] = iDynTreeMEX(1928, self, varargin{:});
+      [varargout{1:nargout}] = iDynTreeMEX(1949, self, varargin{:});
     end
     function delete(self)
       if self.swigPtr
-        iDynTreeMEX(1930, self);
+        iDynTreeMEX(1951, self);
         self.SwigClear();
       end
     end
   end
   methods(Static)
     function varargout = XYRectangleFromOffsets(varargin)
-     [varargout{1:nargout}] = iDynTreeMEX(1929, varargin{:});
+     [varargout{1:nargout}] = iDynTreeMEX(1950, varargin{:});
     end
   end
 end
